@@ -2,19 +2,25 @@ import numpy as np
 import json
 from matplotlib import pyplot
 
+"""
+Python version: 3.7
+Created by: Tim Stahl
+Created on: 21.05.2019
 
-def get_scene_track(file_path: str):
+Script providing methods for track extraction (bounds) from a scenario file as well as the conversion to an occupancy
+grid.
+"""
+
+
+def get_scene_track(file_path: str) -> tuple:
     """
-    Python version: 3.5
-    Created by: Tim Stahl
-    Created on: 21.05.2019
-
-    Documentation:  Sample script extracting the track bounds from a scene file.
+    Method extracting the track bounds from a scene file.
 
     :param file_path:    string holding the path to the scene data file
     :returns (bound_l,   coordinates of the tracks bounds left
               bound_r)   coordinates of the tracks bounds right
     """
+
     # -- read relevant lines from file ---------------------------------------------------------------------------------
     bound_l = None
     bound_r = None
@@ -41,13 +47,9 @@ def get_scene_occupancy(bound_l: np.ndarray,
                         grid_res: float = 0.1,
                         x_range: tuple = (0.0, 100.0),
                         y_range: tuple = (0.0, 100.0),
-                        plot_occupancy=False):
+                        plot_occupancy=False) -> dict:
     """
-    Python version: 3.5
-    Created by: Tim Stahl
-    Created on: 22.05.2019
-
-    Documentation:  Sample script generating an occupancy grid from the bounds stored in a scene file.
+    Method generating an occupancy grid from provided bound coordinate arrays.
 
     :param bound_l:         coordinates of the left bound
     :param bound_r:         coordinates of the right bound
